/****************************************************************************
 * This file is part of the project AqFinance.
 * AqFinance (c) by 2009 Martin Preuss, all rights reserved.
 *
 * The license for this file can be found in the file COPYING which you
 * should have received along with this file.
 ****************************************************************************/


#ifdef HAVE_CONFIG_H
# include <config.h>
#endif


#include "ff_editpartnerstmrule.hpp"
#include "ff_partneredit.hpp"

#include <aqfinance/engine/book/ae_book.h>

#include <gwen-gui-fox16/theme.h>

#include <gwenhywfar/i18n.h>
#include <gwenhywfar/debug.h>


#define I18N(msg) GWEN_I18N_Translate(PACKAGE, msg)
#define I18S(msg) msg


FXDEFMAP(FF_EditPartnerStatementRule) FF_EditPartnerStatementRuleMap[]={
  FXMAPFUNC(SEL_COMMAND, FF_EditPartnerStatementRule::ID_PARTNER_EDIT, FF_EditPartnerStatementRule::onCmdPartnerEdit),
};


FXIMPLEMENT(FF_EditPartnerStatementRule, FXDialogBox,
	    FF_EditPartnerStatementRuleMap, ARRAYNUMBER(FF_EditPartnerStatementRuleMap))



FF_EditPartnerStatementRule::FF_EditPartnerStatementRule(FF_App* a,
                                                         FXComposite *parent,
                                                         const FXString& title,
                                                         FXuint opts,
                                                         FXint x, FXint y, FXint w, FXint h,
                                                         FXint pl, FXint pr, FXint pt, FXint pb,
                                                         FXint hs, FXint vs)
:FF_EditStatementRule(a, parent, title, opts, x, y, w, h, pl, pr, pt, pb, hs, vs)
,m_partnerEdit(NULL) {
  FXHorizontalFrame *hf;

  new FXHorizontalSeparator(m_verticalFrame, LAYOUT_FILL_X | SEPARATOR_GROOVE);

  hf=new FXHorizontalFrame(m_verticalFrame, LAYOUT_FILL_X);
  new FXLabel(hf, I18N("Partner"), NULL, LABEL_NORMAL);
  m_partnerEdit=new FF_PartnerEdit(hf, this, ID_PARTNER_EDIT, LAYOUT_FILL_X);
}



FF_EditPartnerStatementRule::FF_EditPartnerStatementRule()
:FF_EditStatementRule()
,m_partnerEdit(NULL) {
}



FF_EditPartnerStatementRule::~FF_EditPartnerStatementRule() {
}



FXint FF_EditPartnerStatementRule::checkGui(FXbool quiet) {
  int rv;

  rv=FF_EditStatementRule::checkGui(quiet);
  if (rv<0)
    return rv;

  /* TODO: check partner */
  if (m_partnerEdit->getPartnerId()==0) {
    if (!quiet) {
      FXMessageBox::error(this, MBOX_OK,
			  I18N("Input Error"),
                          "%s",
			  I18N("Please select the destination partner"));
      m_partnerEdit->setFocus();
    }
    return GWEN_ERROR_BAD_DATA;
  }

  return 0;
}



FXint FF_EditPartnerStatementRule::toGui(const AE_RULE *r, GWEN_DB_NODE *dbExample) {
  int rv;
  AQDB_ID aid;

  rv=FF_EditStatementRule::toGui(r, dbExample);
  if (rv<0)
    return rv;

  /* set partner */
  m_partnerEdit->reload();

  aid=AE_Rule_GetOwnerId(r);
  if (aid)
    m_partnerEdit->setPartnerId(aid);

  return 0;
}



FXint FF_EditPartnerStatementRule::fromGui(AE_RULE *r) {
  int rv;

  rv=FF_EditStatementRule::fromGui(r);
  if (rv<0)
    return rv;

  /* get partner */
  AE_Rule_SetOwnerType(r, AE_Book_TableType_Partner);
  AE_Rule_SetOwnerId(r, m_partnerEdit->getPartnerId());

  return 0;
}



long FF_EditPartnerStatementRule::onCmdPartnerEdit(FXObject*, FXSelector, void *ptr) {
  if (m_okButton) {
    m_okButton->setFocus();
    changeFocus(m_okButton);
  }
  return 1;
}



bool FF_EditPartnerStatementRule::editRule(FF_App* app,
                                           FXComposite *parent,
                                           const FXString &title,
                                           AE_RULE *r,
                                           GWEN_DB_NODE *dbExample) {
  FF_EditPartnerStatementRule dlg(app, parent, title, DECOR_ALL);
  FXuint dlgres;

  dlg.addDialogLine();
  dlg.resize(440, 400);
  dlg.create();
  dlg.init();
  dlg.toGui(r, dbExample);

  dlg.show(PLACEMENT_VISIBLE);
  dlg.layout();

  dlgres=dlg.execute(PLACEMENT_VISIBLE);
  dlg.fini();
  if (dlgres==0)
    return false;

  dlg.fromGui(r);
  return true;
}


