/****************************************************************************
 * This file is part of the project AqFinance.
 * AqFinance (c) by 2010 Martin Preuss, all rights reserved.
 *
 * The license for this file can be found in the file COPYING which you
 * should have received along with this file.
 ****************************************************************************/

#ifndef FF_INVOICETREE_HPP
#define FF_INVOICETREE_HPP

#include "ff_grouptree.hpp"

#include <fx.h>

#include <aqfinance/engine/book/ae_job.h>
#include <aqfinance/engine/book/ae_partner.h>
#include <aqfinance/engine/book/ae_commodity.h>



class FF_InvoiceTreeItem: public FF_GroupTreeItem {
public:
  FF_InvoiceTreeItem(const FXString &txt,
		     AE_JOB *j,
		     FXIcon* oi=NULL, FXIcon* ci=NULL, void* ptr=NULL);

  virtual ~FF_InvoiceTreeItem();

  AE_JOB *getJob() const { return m_job;};

protected:
  AE_JOB *m_job;
};



class FF_InvoiceTree: public FF_GroupTree {

public:
  FF_InvoiceTree(FXComposite *p, FXObject* tgt=NULL, FXSelector sel=0, FXuint opts=0,
		 FXint x=0, FXint y=0, FXint w=0, FXint h=0);

  virtual ~FF_InvoiceTree();

  FF_InvoiceTreeItem *findInvoiceItem(AQDB_ID id);
  FF_InvoiceTreeItem *findInvoiceItem(FF_GroupTreeItem *grItem, AQDB_ID id);
  FF_InvoiceTreeItem *findInvoiceItem(const AE_JOB *j);

  void addInvoice(const AE_JOB *j);
  void addInvoice(AE_JOB *j);

  AE_JOB *getCurrentInvoice();
  AE_JOB *getFirstSelectedJob();
  void getSelectedInvoices(AE_JOB_LIST2 *jl);

  void getInvoices(AE_JOB_LIST2 *jl, int copyMode);

  void selectInvoice(AQDB_ID id, bool b);
  void selectInvoice(const AE_JOB *j, bool b);
  void makeInvoiceVisible(AQDB_ID id);

  void sortByColumn(int c, bool up);

  void reload();

protected:
  FF_InvoiceTree();


  static FXint sortFunctionUp0(const FXFoldingItem *it1, const FXFoldingItem *it2);
  static FXint sortFunctionDown0(const FXFoldingItem *it1, const FXFoldingItem *it2);

  static FXint sortFunctionUp1(const FXFoldingItem *it1, const FXFoldingItem *it2);
  static FXint sortFunctionDown1(const FXFoldingItem *it1, const FXFoldingItem *it2);

  static FXint sortFunctionUp2(const FXFoldingItem *it1, const FXFoldingItem *it2);
  static FXint sortFunctionDown2(const FXFoldingItem *it1, const FXFoldingItem *it2);

  static FXint sortFunctionUp4(const FXFoldingItem *it1, const FXFoldingItem *it2);
  static FXint sortFunctionDown4(const FXFoldingItem *it1, const FXFoldingItem *it2);

  static FXint sortFunctionUp5(const FXFoldingItem *it1, const FXFoldingItem *it2);
  static FXint sortFunctionDown5(const FXFoldingItem *it1, const FXFoldingItem *it2);

  AE_PARTNER_LIST *m_partners;
  AE_COMMODITY_LIST *m_commodities;
};



#endif




