/****************************************************************************
 * This file is part of the project AqFinance.
 * AqFinance (c) by 2018 Martin Preuss, all rights reserved.
 *
 * The license for this file can be found in the file COPYING which you
 * should have received along with this file.
 ****************************************************************************/

#ifndef FF_SHARETREE_HPP
#define FF_SHARETREE_HPP

#include "ff_grouptree.hpp"

#include <fx.h>

#include <aqfinance/engine/book/ae_share.h>



class FF_ShareTreeItem: public FF_GroupTreeItem {
public:
  FF_ShareTreeItem(AE_SHARE *st, void* ptr=NULL);

  virtual ~FF_ShareTreeItem();

  AE_SHARE *getShare() const { return m_share;};

  virtual FXString getItemText(const FXXCheckTree* list) const;
  virtual FXString getColumnTooltipText(FXint col);

protected:
  AE_SHARE *m_share;
};



class FF_ShareTree: public FF_GroupTree {
  friend class FF_ShareTreeItem;
public:
  enum {
    USECOLOR_NORMAL=0,
    USECOLOR_NOTICE,
    USECOLOR_WARNING
  };

  enum {
    COLUMN_NONE=0,
    COLUMN_NAME=1,
    COLUMN_ISIN,
    COLUMN_DOWNLOADNAME,
    COLUMN_AMOUNT,
    COLUMN_NOTE,
    COLUMN_LOWERLIMIT,
    COLUMN_UPPERLIMIT,
    COLUMN_NEXT_STOCKHOLDER_MEETING,
    COLUMN_LAST_STOCKHOLDER_MEETING,
    COLUMN_NEXT_REPORT_DATE,
    COLUMN_DIVIDEND,

    COLUMN_MAX=100
  };

  FF_ShareTree(FXComposite *p, FXObject* tgt=NULL, FXSelector sel=0, FXuint opts=0,
               FXint x=0, FXint y=0, FXint w=0, FXint h=0);

  virtual ~FF_ShareTree();

  void addColumn(int c, int w=100);

  FF_ShareTreeItem *findShareItem(AQDB_ID id);
  FF_ShareTreeItem *findShareItem(FF_GroupTreeItem *grItem, AQDB_ID id);
  FF_ShareTreeItem *findShareItem(const AE_SHARE *qba);

  void addShare(AE_SHARE *st, bool direct, int useColor);
  void addShares(AE_SHARE_LIST2 *sl, int copyMode, bool direct);

  void addShareToGroup(AE_SHARE *st, AQDB_ID gid, int useColor);
  void addShareToItem(AE_SHARE *st, FF_GroupTreeItem *itemFather, int useColor);

  AE_SHARE *getCurrentShare();
  AE_SHARE *getFirstSelectedShare();
  void getSelectedShares(AE_SHARE_LIST2 *sl, int copyMode);

  void selectShare(AQDB_ID id, bool b);
  void selectShare(const AE_SHARE *st, bool b);
  void makeShareVisible(AQDB_ID id);

  void create();

  void sortByColumn(int c, bool up);
  void addColumn(int c);

protected:
  FF_ShareTree();

  static FXint sortFunctionUpName(const FXFoldingItem *it1, const FXFoldingItem *it2);
  static FXint sortFunctionDownName(const FXFoldingItem *it1, const FXFoldingItem *it2);

  static FXint sortFunctionUpIsin(const FXFoldingItem *it1, const FXFoldingItem *it2);
  static FXint sortFunctionDownIsin(const FXFoldingItem *it1, const FXFoldingItem *it2);

  static FXint sortFunctionUpDownloadName(const FXFoldingItem *it1, const FXFoldingItem *it2);
  static FXint sortFunctionDownDownloadName(const FXFoldingItem *it1, const FXFoldingItem *it2);

  static FXint sortFunctionUpAmount(const FXFoldingItem *it1, const FXFoldingItem *it2);
  static FXint sortFunctionDownAmount(const FXFoldingItem *it1, const FXFoldingItem *it2);

  static FXint sortFunctionUpNote(const FXFoldingItem *it1, const FXFoldingItem *it2);
  static FXint sortFunctionDownNote(const FXFoldingItem *it1, const FXFoldingItem *it2);

  static FXint sortFunctionUpLowerLimit(const FXFoldingItem *it1, const FXFoldingItem *it2);
  static FXint sortFunctionDownLowerLimit(const FXFoldingItem *it1, const FXFoldingItem *it2);

  static FXint sortFunctionUpUpperLimit(const FXFoldingItem *it1, const FXFoldingItem *it2);
  static FXint sortFunctionDownUpperLimit(const FXFoldingItem *it1, const FXFoldingItem *it2);

  static FXint sortFunctionUpNextStockholdersMeeting(const FXFoldingItem *it1, const FXFoldingItem *it2);
  static FXint sortFunctionDownNextStockholdersMeeting(const FXFoldingItem *it1, const FXFoldingItem *it2);

  static FXint sortFunctionUpLastStockholdersMeeting(const FXFoldingItem *it1, const FXFoldingItem *it2);
  static FXint sortFunctionDownLastStockholdersMeeting(const FXFoldingItem *it1, const FXFoldingItem *it2);

  static FXint sortFunctionUpNextNextReportDate(const FXFoldingItem *it1, const FXFoldingItem *it2);
  static FXint sortFunctionDownNextNextReportDate(const FXFoldingItem *it1, const FXFoldingItem *it2);

  static FXint sortFunctionUpDividend(const FXFoldingItem *it1, const FXFoldingItem *it2);
  static FXint sortFunctionDownDividend(const FXFoldingItem *it1, const FXFoldingItem *it2);

  static FXint sortFunctionUpNextReportDate(const FXFoldingItem *it1, const FXFoldingItem *it2);
  static FXint sortFunctionDownNextReportDate(const FXFoldingItem *it1, const FXFoldingItem *it2);


  int m_columns;
  int m_columnTypes[COLUMN_MAX];
};



#endif




